@@ -24,21 +24,22 @@
 #include <pds/pdsra.h>
 #include <pds/pdsrv.h>
 #include <pds/pdssn.h>
-#include <pds/pdsnivector.h>
-#include <pds/pdsnvector.h>
-#include <pds/pdsneuronml.h>
-
-
-////////////////////////////////////////////////////////////////////////////////
-////  Trabajando con PdsNeuronML                                              ////
-////////////////////////////////////////////////////////////////////////////////
+#include <pds/pdsnn.h>
 
 
 /** \fn PdsNeuronML *pds_neuronml_new(const PdsVector *L)
- *  \brief Crea una estructura de tipo PdsNeuronML e inicia con cero todos los 
- *  elementos. Pero con un error mínimo de 1/sqrt(2), que indica una incertidumbre 
- *  en la mitad de los datos de salida y los demás datos son aciertos. El valor de
- *  de Alpha se inicia con 0.5.
+ *  \brief Crea una estructura de tipo PdsNeuronML.
+ *
+ *  <ul>
+ *  <li>Inicia con cero todos los Pesos. </li>
+ *  <li>El máximo margen de error RMS aceptado en la salida de la estructura 
+    PdsNeuronML es PDS_DEFAULT_MAX_RMS_ERROR.</li>
+ *  <li>El valor de de Alpha se inicia con PDS_DEFAULT_ALPHA.</li>
+ *  <li>El valor U se inicia con 1.0.</li>
+ *  <li>El valor Sigma se inicia con 1.0.</li>
+ *  <li>El valor func(x) se inicia con tanh(x/2).</li>
+ *  </ul> 
+ *  
  *  \param[in] L Es un vector con el numero de elementos por capas.
  *  \return Un puntero al vector de tipo PdsNeuronML.
  *  \ingroup PdsNeuronMLGroup
@@ -115,15 +116,16 @@ PdsNeuronML *pds_neuronml_new(const PdsVector *L)
 		
 	}
 
-	pds_nvector_connect_input_data(NeuronML->Layer[0],NeuronML->LayerInput);
+	pds_nvector_connect_input_with_nivector(NeuronML->Layer[0],NeuronML->LayerInput);
 	for(i=1;i<NeuronML->N;i++)
 	{
 		pds_nvector_connect_input(NeuronML->Layer[i],NeuronML->Layer[i-1]);
 	}
 
-	NeuronML->Error=0.707106781;
-	NeuronML->Alpha=0.5;
-	NeuronML->MaxIter=0;
+	NeuronML->MaxError=PDS_DEFAULT_MAX_RMS_ERROR;
+	NeuronML->Alpha=PDS_DEFAULT_ALPHA;
+	NeuronML->MaxIter=PDS_DEFAULT_MAX_ITER;
+
 	NeuronML->Iter=0;
 	NeuronML->ShowPrintf=0;
 
@@ -132,14 +134,29 @@ PdsNeuronML *pds_neuronml_new(const PdsVector *L)
 }
 
 
-/** \fn PdsNeuronML *pds_neuronml_new_load_data(const char *mlayerfile)
+/** \fn PdsNeuronML *pds_neuronml_new_load_data(const char *mlayer_filename)
  *  \brief Crea una estructura de tipo PdsNeuronML e inicia todos los elementos.
  *  desde un archivo de texto.
- *  \param[in] mlayerfile Es el archivo de texto de donde se leen los datos.
+ *
+ *  Los datos cargados son :
+ *  <ul>
+ *  <li>N, el numero de capas. </li>
+ *  <li>MaxError, El máximo margen de error RMS aceptado en la salida.</li>
+ *  <li>Alpha, El factor de aprendizaje.</li>
+ *  <li>MaxIter, El máximo número de iteraciones.</li>
+ *  <li>Iter, El número de iteraciones del último entrenamiento</li>.
+ *  <li>ShowPrintf, Si la estructura muestra información adicional.</li>
+ *  <li>L, Vector de N+1 elementos con el número de neuronas por capa.</li>
+ *  <li>Vector de pesos de neurona.</li>
+ *  <li>Valor de U y Valor de Sigma</li>
+ *  <li>...</li>
+ *  </ul> 
+ *  
+ *  \param[in] mlayer_filename Es el archivo de texto de donde se leen los datos.
  *  \return Un puntero al vector de tipo PdsNeuronML.
  *  \ingroup PdsNeuronMLGroup
  */
-PdsNeuronML *pds_neuronml_new_load_data(const char *mlayerfile)
+PdsNeuronML *pds_neuronml_new_load_data(const char *mlayer_filename)
 {
 	PdsNeuronML *NeuronML=NULL;
 	FILE *fd=NULL;
@@ -147,9 +164,9 @@ PdsNeuronML *pds_neuronml_new_load_data(const char *mlayerfile)
 	PdsNnReal x;
 	int tmp;
 
-	if(mlayerfile==NULL)	return NULL;
+	if(mlayer_filename==NULL)	return NULL;
 
-	fd=fopen(mlayerfile,"r");
+	fd=fopen(mlayer_filename,"r");
 	if(fd==NULL)	return NULL;
 
 	// Reservo memoria de la estructura.
@@ -166,7 +183,7 @@ PdsNeuronML *pds_neuronml_new_load_data(const char *mlayerfile)
 
 	if(feof(fd)==0)	
 	{
-		tmp=fscanf(fd,"%e",&(NeuronML->Error));
+		tmp=fscanf(fd,"%e",&(NeuronML->MaxError));
 		if(tmp==0)	{free(NeuronML);	return NULL;}
 	}
 	else		{free(NeuronML);	return NULL;}
@@ -265,7 +282,7 @@ PdsNeuronML *pds_neuronml_new_load_data(const char *mlayerfile)
 		
 	}
 
-	pds_nvector_connect_input_data(NeuronML->Layer[0],NeuronML->LayerInput);
+	pds_nvector_connect_input_with_nivector(NeuronML->Layer[0],NeuronML->LayerInput);
 	for(i=1;i<NeuronML->N;i++)
 	{
 		pds_nvector_connect_input(NeuronML->Layer[i],NeuronML->Layer[i-1]);
@@ -279,27 +296,42 @@ PdsNeuronML *pds_neuronml_new_load_data(const char *mlayerfile)
 }
 
 
-/** \fn int pds_neuronml_save_data(const PdsNeuronML *NeuronML, const char *mlayerfile)
+/** \fn int pds_neuronml_save_data(const PdsNeuronML *NeuronML, const char *mlayer_filename)
  *  \brief Salva una estructura de tipo PdsNeuronML en un archivo de texto.
+ *
+ *  Los datos salvados son :
+ *  <ul>
+ *  <li>N, el numero de capas. </li>
+ *  <li>MaxError, El máximo margen de error RMS aceptado en la salida.</li>
+ *  <li>Alpha, El factor de aprendizaje.</li>
+ *  <li>MaxIter, El máximo número de iteraciones.</li>
+ *  <li>Iter, El número de iteraciones del último entrenamiento</li>.
+ *  <li>ShowPrintf, Si la estructura muestra información adicional.</li>
+ *  <li>L, Vector de N+1 elementos con el número de neuronas por capa.</li>
+ *  <li>Vector de pesos de neurona.</li>
+ *  <li>Valor de U y Valor de Sigma</li>
+ *  <li>...</li>
+ *  </ul> 
+ *  
  *  \param[in] NeuronML Es la red neuronal multicapa a salvar.
- *  \param[in] mlayerfile Es el archivo de texto donde se guardará la red.
- *  \return TRUE si todo fue bien o FALSE si no. (ejem: NeuronML==NULL o mlayerfile=NULL).
+ *  \param[in] mlayer_filename Es el archivo de texto donde se guardará la red.
+ *  \return TRUE si todo fue bien o FALSE si no. (ejem: NeuronML==NULL o mlayer_filename=NULL).
  *  \ingroup PdsNeuronMLGroup
  */
-int pds_neuronml_save_data(const PdsNeuronML *NeuronML, const char *mlayerfile)
+int pds_neuronml_save_data(const PdsNeuronML *NeuronML, const char *mlayer_filename)
 {
 	FILE *fd=NULL;
 	PdsNnNatural i;
 
 	if(NeuronML==NULL)	return FALSE;
-	if(mlayerfile==NULL)	return FALSE;
+	if(mlayer_filename==NULL)	return FALSE;
 
-	fd=fopen(mlayerfile,"w");
+	fd=fopen(mlayer_filename,"w");
 	if(fd==NULL)	return FALSE;
 
 	fprintf(fd,"%u\t",NeuronML->N);
 
-	fprintf(fd,"%e\t",NeuronML->Error);
+	fprintf(fd,"%e\t",NeuronML->MaxError);
 
 	fprintf(fd,"%e\t",NeuronML->Alpha);
 
@@ -312,7 +344,7 @@ int pds_neuronml_save_data(const PdsNeuronML *NeuronML, const char *mlayerfile)
 	for(i=0;i<=NeuronML->N;i++)
 	{	
 		if(i!=NeuronML->N)	fprintf(fd,"%u\t",NeuronML->L[i]);
-		else			fprintf(fd,"%u\n",NeuronML->L[i]);
+		else			    fprintf(fd,"%u\n",NeuronML->L[i]);
 	}
 
 	pds_neuronml_fprintf(NeuronML,fd);
@@ -323,22 +355,27 @@ int pds_neuronml_save_data(const PdsNeuronML *NeuronML, const char *mlayerfile)
 }
 
 
-/** \fn int pds_neuronml_set_max_error(PdsNeuronML *NeuronML,PdsNnReal Error)
- *  \brief Coloca el maximo error aceptado, cualquier valor de error menor
+/** \fn int pds_neuronml_set_max_error(PdsNeuronML *NeuronML,PdsNnReal MaxError)
+ *  \brief Coloca el maximo margen error RMS aceptado en la salida de la estructura
+ *  PdsNeuronML.
+ *
+ *  Cualquier valor de error que es menor
  *  provoca que se detenga el algoritmo de aprendizaje.
  *  \param[in,out] NeuronML Red neuronal Multi capa a trabajar.
- *  \param[in] Error Máximo error aceptado.
+ *  \param[in] MaxError Máximo error aceptado.
+ *  El valor cero no es aceptado, en su defecto es escrito PDS_DEFAULT_MAX_RMS_ERROR.
+ *  Valores negativos no son aceptados, en su defecto es escrito |MaxError|.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NeuronML==NULL). 
  *  \ingroup PdsNeuronMLGroup
  */
-int pds_neuronml_set_max_error(PdsNeuronML *NeuronML,PdsNnReal Error)
+int pds_neuronml_set_max_error(PdsNeuronML *NeuronML,PdsNnReal MaxError)
 {
 	PdsNnReal e;
 	if(NeuronML==NULL)	return FALSE;
 
-	e=fabs(Error);
-	if(e!=0.0)	NeuronML->Error=e;
-	else		NeuronML->Error=0.05;
+	e=fabs(MaxError);
+	if(e!=0.0)	NeuronML->MaxError=e;
+	else		NeuronML->MaxError=PDS_DEFAULT_MAX_RMS_ERROR;
 	
 	return TRUE;
 }
@@ -361,17 +398,17 @@ int pds_neuronml_set_alpha(PdsNeuronML *NeuronML,PdsNnReal Alpha)
 }
 
 
-/** \fn int pds_neuronml_set_max_number_iterations(PdsNeuronML *NeuronML,PdsNnNatural MaxIter)
+/** \fn int pds_neuronml_set_max_iterations(PdsNeuronML *NeuronML,PdsNnNatural MaxIter)
  *  \brief Coloca el máximo numero de iteraciones aceptado, cualquier valor mayor
- *  provoca que se detenga el algoritmo de aprendizaje. si este número es cero
+ *  provoca que se detenga el algoritmo de aprendizaje pds_neuronml_training(). si este número es cero
  *  entonces el algoritmo continua hasta que el error en la salida sea menor que
- *  NeuronML->Error.
+ *  NeuronML->MaxError.
  *  \param[in,out] NeuronML Red neuronal Multi capa a trabajar.
  *  \param[in] MaxIter Número máximo de iteraciones.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NeuronML==NULL). 
  *  \ingroup PdsNeuronMLGroup
  */
-int pds_neuronml_set_max_number_iterations(PdsNeuronML *NeuronML,PdsNnNatural MaxIter)
+int pds_neuronml_set_max_iterations(PdsNeuronML *NeuronML,PdsNnNatural MaxIter)
 {
 
 	if(NeuronML==NULL)	return FALSE;
@@ -383,8 +420,8 @@ int pds_neuronml_set_max_number_iterations(PdsNeuronML *NeuronML,PdsNnNatural Ma
 
 
 /** \fn int pds_neuronml_get_number_iterations(const PdsNeuronML *NeuronML,PdsNnNatural *Iter)
- *  \brief Devuelve el número de iteraciones del ultimo entrenamiento hecho con
- *  la función pds_neuronml_training.
+ *  \brief Devuelve el número de iteraciones del último entrenamiento hecho con
+ *  la función pds_neuronml_training().
  *  \param[in,out] NeuronML Red neuronal Multi capa a trabajar.
  *  \param[in] Iter Número de iteraciones del último entrenamiento.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NeuronML==NULL). 
@@ -419,14 +456,14 @@ int pds_neuronml_enable_printf(PdsNeuronML *NeuronML)
 }
 
 
-/** \fn int pds_neuronml_init_uniform_synaptic_weight(PdsNeuronML *NeuronML,PdsUniform *RV)
+/** \fn int pds_neuronml_init_weight_uniform(PdsNeuronML *NeuronML,PdsUniform *RV)
  *  \brief Inicializa todos los pesos usando una variable aleatoria uniforme.
  *  \param[in,out] NeuronML Red neuronal Multi capa a trabajar.
  *  \param[in] RV Variable aleatoria uniforme.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NeuronML==NULL, RV==NULL). 
  *  \ingroup PdsNeuronMLGroup
  */
-int pds_neuronml_init_uniform_synaptic_weight(PdsNeuronML *NeuronML,PdsUniform *RV)
+int pds_neuronml_init_weight_uniform(PdsNeuronML *NeuronML,PdsUniform *RV)
 {
 	PdsNnNatural i;
 	
@@ -435,21 +472,21 @@ int pds_neuronml_init_uniform_synaptic_weight(PdsNeuronML *NeuronML,PdsUniform *
 
 	for(i=0;i<NeuronML->N;i++)
 	{
-		pds_nvector_init_uniform_synaptic_weight(NeuronML->Layer[i],RV);
+		pds_nvector_init_weight_uniform(NeuronML->Layer[i],RV);
 	}
 
 	return TRUE;
 }
 
 
-/** \fn int pds_neuronml_init_uniform_u(PdsNeuronML *NeuronML,PdsUniform *RV)
+/** \fn int pds_neuronml_init_u_uniform(PdsNeuronML *NeuronML,PdsUniform *RV)
  *  \brief Inicializa todos los umbrales U usando una variable aleatoria uniforme.
  *  \param[in,out] NeuronML Red neuronal Multi capa a trabajar.
  *  \param[in] RV Variable aleatoria uniforme.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NeuronML==NULL, RV==NULL). 
  *  \ingroup PdsNeuronMLGroup
  */
-int pds_neuronml_init_uniform_u(PdsNeuronML *NeuronML,PdsUniform *RV)
+int pds_neuronml_init_u_uniform(PdsNeuronML *NeuronML,PdsUniform *RV)
 {
 	PdsNnNatural i;
 	
@@ -458,7 +495,7 @@ int pds_neuronml_init_uniform_u(PdsNeuronML *NeuronML,PdsUniform *RV)
 
 	for(i=0;i<NeuronML->N;i++)
 	{
-		pds_nvector_init_uniform_u(NeuronML->Layer[i],RV);
+		pds_nvector_init_u_uniform(NeuronML->Layer[i],RV);
 	}
 
 	return TRUE;
@@ -487,49 +524,60 @@ int pds_neuronml_set_sigma(PdsNeuronML *NeuronML,PdsNnReal Sigma)
 }
 
 
-/** \fn int pds_neuronml_iterate(PdsNeuronML *NeuronML,const PdsVector *X,PdsVector *Y)
+/** \fn int pds_neuronml_iterate(PdsNeuronML *NeuronML,const PdsVector *Input,PdsVector *Output)
  *  \brief Itera la red neuronal multicapa NeuronML.
+ *  \f[ \theta_j=\sum_{k=0}^{N_{d}-1}{W_{kj}X_k} - U_j \f]
+ *  \f[ y_j \leftarrow func\left(\frac{\theta_j}{\sigma_j}\right) \f]
  *  \param[in,out] NeuronML Red neuronal Multi capa a trabajar.
- *  \param[in] X Datos de entrada de la red neuronal multicapa.
- *  \param[out] Y Datos de salida de la red neuronal multicapa.
+ *  \param[in] Input Datos de entrada de la red neuronal multicapa.
+ *  \param[out] Output Datos de salida de la red neuronal multicapa.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NeuronML==NULL, o tamaños de
  *  vectores incompatibles). 
  *  \ingroup PdsNeuronMLGroup
  */
-int pds_neuronml_iterate(PdsNeuronML *NeuronML,const PdsVector *X,PdsVector *Y)
+int pds_neuronml_iterate(PdsNeuronML *NeuronML,const PdsVector *Input,PdsVector *Output)
 {
 	PdsNnNatural N,i;
 
 	if(NeuronML==NULL)	return FALSE;
 
 	N=NeuronML->N;
-	if(NeuronML->LayerInput->Nel!=X->Nel)	return FALSE;
-	if(NeuronML->Layer[N-1]->Nel!=Y->Nel)	return FALSE;
+	if(NeuronML->LayerInput->Nel!=Input->Nel)	return FALSE;
+	if(NeuronML->Layer[N-1]->Nel!=Output->Nel)	return FALSE;
 
-	pds_nivector_set_input(NeuronML->LayerInput,X);
+	pds_nivector_set_input(NeuronML->LayerInput,Input);
 
 	for(i=0;i<N;i++)	pds_nvector_iterate(NeuronML->Layer[i]);
 
-	pds_nvector_get_output(NeuronML->Layer[N-1],Y);
+	pds_nvector_get_output(NeuronML->Layer[N-1],Output);
 
 	return TRUE;
 }
 
 
 
-/** \fn int pds_neuronml_training(PdsNeuronML *NeuronML,const PdsVector *X,PdsVector *Y)
- *  \brief Entrena la red neuronal multicapa NeuronML. Usa el valor de Y como 
- *  entrenamiento, para finalizar carga el nuevo valor de Y.
- *  \f[ e^{inputs}_i = W[i] e \f].
- *  \f[ W[i] = W[i] + \alpha e f'(\theta) \frac{X[i]}{X^TX} \f].
+/** \fn int pds_neuronml_training(PdsNeuronML *NeuronML,const PdsVector *Input,PdsVector *Output)
+ *  \brief Entrena la red neuronal multicapa NeuronML. Usa el valor de Output como 
+ *  entrenamiento, para finalizar carga el nuevo valor de salida en Output.
+ *
+ *  Bucle de retropropagación e iteración :
+ *  <ul>
+ *  <li>pds_nvector_evaluate_error()</li>
+ *  <li>pds_nvector_backpropagate_error() : \f$ e_k \leftarrow e_k + \frac{func'\left(\frac{\theta_j}{\sigma_j}\right)}{\sigma_j} W_{kj} e_j \f$ </li>
+ *  <li>pds_nvector_update_weight() : \f$ W_{kj} = W_{kj} + \alpha e_j \frac{func'\left(\frac{\theta_j}{\sigma_j}\right)}{\sigma_j} \frac{X_{k}}{X^TX} \f$</li>
+ *  <li>pds_neuronml_iterate()</li>
+ *  </ul>
+ *  El bucle es repetido hasta que el error cuadratico medio en la salida sea menor
+ *  NeuronML->MaxError o que el numero de iteraciones sea mayor que NeuronML->MaxIter
+ *  (Solo si NeuronML->MaxIter es diferente de cero).
  *  \param[in,out] NeuronML Red neuronal Multi capa a trabajar.
- *  \param[in] X Datos de entrada de la red neuronal multicapa.
- *  \param[in] Y Datos esperados de salida de la red neuronal multicapa.
+ *  \param[in] Input Datos de entrada de la red neuronal multicapa.
+ *  \param[in,out] Output Datos esperados de salida de la red neuronal multicapa.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NeuronML==NULL, o tamaños de
  *  vectores incompatibles). 
  *  \ingroup PdsNeuronMLGroup
  */
-int pds_neuronml_training(PdsNeuronML *NeuronML,const PdsVector *X,PdsVector *Y)
+int pds_neuronml_training(PdsNeuronML *NeuronML,const PdsVector *Input,PdsVector *Output)
 {
 	PdsNnNatural N,i,j;
 	PdsNnReal e;
@@ -538,20 +586,20 @@ int pds_neuronml_training(PdsNeuronML *NeuronML,const PdsVector *X,PdsVector *Y)
 	if(NeuronML==NULL)	return FALSE;
 
 	N=NeuronML->N;
-	if(NeuronML->LayerInput->Nel!=X->Nel)	return FALSE;
-	if(NeuronML->Layer[N-1]->Nel!=Y->Nel)	return FALSE;
+	if(NeuronML->LayerInput->Nel!=Input->Nel)	return FALSE;
+	if(NeuronML->Layer[N-1]->Nel!=Output->Nel)	return FALSE;
 
-	pds_nivector_set_input(NeuronML->LayerInput,X);
+	pds_nivector_set_input(NeuronML->LayerInput,Input);
 
 	for(i=0;i<N;i++)	pds_nvector_iterate(NeuronML->Layer[i]);
 
-	pds_nvector_evaluate_e(NeuronML->Layer[N-1],Y);
+	pds_nvector_evaluate_error(NeuronML->Layer[N-1],Output);
 
 	pds_nvector_get_rms_error(NeuronML->Layer[N-1],&e);
 
 
 	j=0;
-	while(e>(NeuronML->Error))
+	while(e>(NeuronML->MaxError))
 	{
 		for(i=0;i<N;i++)
 		pds_nvector_backpropagate_error(NeuronML->Layer[N-1-i]);
@@ -559,14 +607,14 @@ int pds_neuronml_training(PdsNeuronML *NeuronML,const PdsVector *X,PdsVector *Y)
 		for(i=0;i<N;i++)
 		{
 			pds_neuron_get_xtx(NeuronML->Layer[i]->V[0],&XtX);
-			pds_nvector_update_weight_norm(NeuronML->Layer[i],NeuronML->Alpha,XtX);
+			pds_nvector_update_weight(NeuronML->Layer[i],(NeuronML->Alpha)/XtX);
 		}
 
 		pds_nivector_iterate(NeuronML->LayerInput);
 		for(i=0;i<N;i++)	
 		pds_nvector_iterate(NeuronML->Layer[i]);
 
-		pds_nvector_evaluate_e(NeuronML->Layer[N-1],Y);
+		pds_nvector_evaluate_error(NeuronML->Layer[N-1],Output);
 
 		pds_nvector_get_rms_error(NeuronML->Layer[N-1],&e);
 
@@ -574,7 +622,7 @@ int pds_neuronml_training(PdsNeuronML *NeuronML,const PdsVector *X,PdsVector *Y)
 		if((j >= NeuronML->MaxIter)&&(NeuronML->MaxIter!=0))	break;
 	}
 
-	pds_nvector_get_output(NeuronML->Layer[N-1],Y);
+	pds_nvector_get_output(NeuronML->Layer[N-1],Output);
 
 	NeuronML->Iter=j;
 
@@ -583,12 +631,13 @@ int pds_neuronml_training(PdsNeuronML *NeuronML,const PdsVector *X,PdsVector *Y)
 
 
 /** \fn int pds_neuronml_get_hard_vote(const PdsNeuronML *NeuronML,PdsNnReal *Vote)
- *  \brief Evalúa una votación de todos los valores de salida Y[0] de las
- *  neuronas de salida de la red neuronal multicapa, se considera como un voto 
- *  positivo "+1" cualquier valor mayor o igual a "0". Se considera como un voto 
- *  negativo "-1" cualquier valor menor a "0". Luego se realiza la suma con signo 
- *  de las votaciones.
- *  \param[in,out] NeuronML Red neuronal Multi capa a trabajar.
+ *  \brief Evalúa una votación con desición abrupta de los valores de salida
+ *  de la red neuronal multicapa.
+ *
+ *  Se considera como un voto positivo "+1" cualquier valor mayor o igual a "0". 
+ *  Se considera como un voto negativo "-1" cualquier valor menor a "0". 
+ *  Luego se realiza la suma con signo de las votaciones.
+ *  \param[in] NeuronML Red neuronal Multi capa a trabajar.
  *  \param[out] Vote Valor de la votación abrupta.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
  *  \ingroup PdsNeuronMLGroup
@@ -606,10 +655,11 @@ int pds_neuronml_get_hard_vote(const PdsNeuronML *NeuronML,PdsNnReal *Vote)
 
 
 /** \fn int pds_neuronml_get_soft_vote(const PdsNeuronML *NeuronML,PdsNnReal *Vote)
- *  \brief Evalúa una votación de todos los valores de salida Y[0] de las
- *  neuronas del vector de salida de la red neuronal multicapa, se realiza una 
- *  suma simple de todos los valores de salida.
- *  \param[in,out] NeuronML Red neuronal Multi capa a trabajar.
+ *  \brief Evalúa una votación con desición suave de los valores de salida
+ *  de la red neuronal multicapa. 
+ *
+ *  Se realiza una suma simple de todos los valores de salida.
+ *  \param[in] NeuronML Red neuronal Multi capa a trabajar.
  *  \param[out] Vote Valor de la votación suave.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
  *  \ingroup PdsNeuronMLGroup
@@ -629,6 +679,7 @@ int pds_neuronml_get_soft_vote(const PdsNeuronML *NeuronML,PdsNnReal *Vote)
 /** \fn int pds_neuronml_fprintf(const PdsNeuronML *NeuronML, FILE *fd)
  *  \brief Guarda en un archivo de texto los pesos W[i], el valor de U y Sigma.
  *  Ocupando una linea cada uno, y separando los elementos por un TAB.
+ *  (neurona por neurona)
  *  \param[in] NeuronML La estructura multicapa a leer.
  *  \param[in,out] fd Manejador del fichero a escribir.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NeuronML==NULL o fd==NULL). 
@@ -655,6 +706,7 @@ int pds_neuronml_fprintf(const PdsNeuronML *NeuronML, FILE *fd)
 /** \fn int pds_neuronml_fscanf(PdsNeuronML *NeuronML, FILE *fd)
  *  \brief Lee de un archivo de texto los pesos W[i], el valor de U  y Sigma.
  *  Ocupando una linea cada uno, y separando los elementos por un TAB.
+ *  (neurona por neurona)
  *  \param[out] NeuronML La estructura multicapa a escribir.
  *  \param[in,out] fd Manejador del fichero a escribir.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NeuronML==NULL o fd==NULL). 
@@ -681,6 +733,7 @@ int pds_neuronml_fscanf(PdsNeuronML *NeuronML, FILE *fd)
 
 /** \fn int pds_neuronml_fwrite(const PdsNeuronML *NeuronML, FILE *fd)
  *  \brief Guarda en un archivo binario los pesos W[i], el valor de U y Sigma.
+ *  (neurona por neurona)
  *  \param[in] NeuronML La estructura multicapa a leer.
  *  \param[in,out] fd Manejador del fichero binario a escribir.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NeuronML==NULL o fd==NULL). 
@@ -706,6 +759,7 @@ int pds_neuronml_fwrite(const PdsNeuronML *NeuronML, FILE *fd)
 
 /** \fn int pds_neuronml_fread(PdsNeuronML *NeuronML, FILE *fd)
  *  \brief Lee de un archivo binario los pesos W[i], el valor de U  y Sigma.
+ *  (neurona por neurona)
  *  \param[out] NeuronML La estructura multicapa a escribir.
  *  \param[in,out] fd Manejador del fichero binario a escribir.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NeuronML==NULL o fd==NULL). 
