@@ -28,20 +28,15 @@
 #include <pds/pdsnvector.h>
 
 
-////////////////////////////////////////////////////////////////////////////////
-////  Trabajando con PdsNVector                                              ////
-////////////////////////////////////////////////////////////////////////////////
-
-
-/** \fn PdsNVector *pds_nvector_new(PdsNnNatural Nel,PdsNnNatural Ninputs)
+/** \fn PdsNVector *pds_nvector_new(PdsNnNatural Nel,PdsNnNatural Nd)
  *  \brief Crea un vector de neuronas de tipo PdsNVector e inicia con cero todos 
- *  los pesos y umbrales.
+ *  los pesos,  U=1.0 e Sigma=1.0.
  *  \param[in] Nel Es el número de elementos del vector.
- *  \param[in] Ninputs Es el número de entradas de cada neurona del vector.
+ *  \param[in] Nd Es el número de entradas de cada neurona del vector.
  *  \return Un puntero al vector de tipo PdsNVector.
  *  \ingroup PdsNVectorGroup
  */
-PdsNVector *pds_nvector_new(PdsNnNatural Nel,PdsNnNatural Ninputs)
+PdsNVector *pds_nvector_new(PdsNnNatural Nel,PdsNnNatural Nd)
 {
 	PdsNVector *NVector=NULL;
 	PdsNnNatural i,j;
@@ -64,7 +59,7 @@ PdsNVector *pds_nvector_new(PdsNnNatural Nel,PdsNnNatural Ninputs)
 
 	for(i=0;i<NVector->Nel;i++)
 	{	
-		NVector->V[i]=pds_neuron_new(Ninputs);
+		NVector->V[i]=pds_neuron_new(Nd);
 		if(NVector->V[i]==NULL)
 		{
 			for(j=0;j<i;j++)	pds_neuron_free(NVector->V[j]);
@@ -73,13 +68,11 @@ PdsNVector *pds_nvector_new(PdsNnNatural Nel,PdsNnNatural Ninputs)
 		}
 	}
 
-	NVector->ID=0;
-
 	return NVector;
 }
 
 
-/** \fn int pds_nvector_init_uniform_synaptic_weight(PdsNVector *NVector,PdsUniform *RV)
+/** \fn int pds_nvector_init_weight_uniform(PdsNVector *NVector,PdsUniform *RV)
  *  \brief Inicia aleatoriamente siguiendo una distribución uniforme, los pesos
  *  de todas las neuronas del vector.
  *  \param[in,out] NVector El vector a escribir.
@@ -87,7 +80,7 @@ PdsNVector *pds_nvector_new(PdsNnNatural Nel,PdsNnNatural Ninputs)
  *  \return TRUE si todo fue bien o FALSE si no (ej: Neuron==NULL). 
  *  \ingroup PdsNVectorGroup
  */
-int pds_nvector_init_uniform_synaptic_weight(PdsNVector *NVector,PdsUniform *RV)
+int pds_nvector_init_weight_uniform(PdsNVector *NVector,PdsUniform *RV)
 {
 	PdsNnNatural i,j;
 	PdsNnReal m;
@@ -100,7 +93,7 @@ int pds_nvector_init_uniform_synaptic_weight(PdsNVector *NVector,PdsUniform *RV)
 		for(j=0;j<NVector->V[i]->Nel;j++)
 		{
 			pds_uniform_get_value(RV,&m);
-			pds_neuron_set_synaptic_weight(NVector->V[i],j,m);
+			pds_neuron_set_weight(NVector->V[i],j,m);
 		}
 	}
 
@@ -130,15 +123,15 @@ int pds_nvector_set_sigma(PdsNVector *NVector,PdsNnReal Sigma)
 
 
 
-/** \fn int pds_nvector_init_uniform_u(PdsNVector *NVector,PdsUniform *RV)
+/** \fn int pds_nvector_init_u_uniform(PdsNVector *NVector,PdsUniform *RV)
  *  \brief Coloca de forma aleatoria siguiendo una distribucion uniforme, el 
  *  valor de  U de las Neuronas.
- *  \param[in,out] NVector La neurona a escribir.
+ *  \param[in,out] NVector El vector de neurons a escribir.
  *  \param[in] RV Variable aleatoria uniforme.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
  *  \ingroup PdsNVectorGroup
  */
-int pds_nvector_init_uniform_u(PdsNVector *NVector,PdsUniform *RV)
+int pds_nvector_init_u_uniform(PdsNVector *NVector,PdsUniform *RV)
 {
 	PdsNnNatural i;
 	PdsNnReal m;
@@ -158,7 +151,7 @@ int pds_nvector_init_uniform_u(PdsNVector *NVector,PdsUniform *RV)
 
 /** \fn int pds_nvector_get_output(const PdsNVector *NVector,PdsVector *Y)
  *  \brief Devuelve el valor de la salida Y de las Neuronas.
- *  \param[in] NVector La neurona en consulta.
+ *  \param[in] NVector El vector de neuronas en consulta.
  *  \param[out] Y Vector donde se cargará los valores de la salida Y.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL, Y==NULL o
  *  tamaños distintos). 
@@ -178,30 +171,31 @@ int pds_nvector_get_output(const PdsNVector *NVector,PdsVector *Y)
 }
 
 
-/** \fn int pds_nvector_connect_input(PdsNVector *NVector,PdsNVector *NVectorX)
- *  \brief Conecta el valor de salida Y de las Neuronas del vector NVectorX con 
+/** \fn int pds_nvector_connect_input(PdsNVector *NVector,PdsNVector *NVectorBefore)
+ *  \brief Conecta el valor de salida Y de las Neuronas del vector NVectorBefore con 
  *  las entradas X[id] de las neuronas del vector NVector.
- *  Si existen mas entradas de NVector que salidas de NVectorX las entradas quedan
+ *
+ *  Si existen mas entradas de NVector que salidas de NVectorBefore las entradas quedan
  *  desconectadas cargadas con NULL.
- *  Si existen menos entradas de NVector que salidas de NVectorX las salidas quedan
+ *  Si existen menos entradas de NVector que salidas de NVectorBefore las salidas quedan
  *  desconectadas.
  *  \param[in,out] NVector El vector de neuronas a trabajar.
- *  \param[in,out] NVectorX El vector de neuronas que se conectará a las entradas 
+ *  \param[in,out] NVectorBefore El vector de neuronas que se conectará a las entradas 
  *  X[id] de NVector.
- *  \return TRUE si todo fue bien o FALSE si no(ej: NVector==NULL, NVectorX==NULL). 
+ *  \return TRUE si todo fue bien o FALSE si no(ej: NVector==NULL, NVectorBefore==NULL). 
  *  \ingroup PdsNVectorGroup
  */
-int pds_nvector_connect_input(PdsNVector *NVector,PdsNVector *NVectorX)
+int pds_nvector_connect_input(PdsNVector *NVector,PdsNVector *NVectorBefore)
 {
 	PdsNnNatural i,j;
 
 	if(NVector ==NULL)		return FALSE;
-	if(NVectorX==NULL)		return FALSE;
+	if(NVectorBefore==NULL)		return FALSE;
 
 	for(i=0;i<NVector->Nel;i++)
 	{
-		for(j=0;(j<NVector->V[i]->Nel)&&(j<NVectorX->Nel);j++)
-		NVector->V[i]->X[j]=NVectorX->V[j]->Y;
+		for(j=0;(j<NVector->V[i]->Nel)&&(j<NVectorBefore->Nel);j++)
+		NVector->V[i]->X[j]=NVectorBefore->V[j]->Y;
 
 		for(;j<NVector->V[i]->Nel;j++)
 		NVector->V[i]->X[j]=NULL;
@@ -210,9 +204,10 @@ int pds_nvector_connect_input(PdsNVector *NVector,PdsNVector *NVectorX)
 }
 
 
-/** \fn int pds_nvector_connect_input_data(PdsNVector *NVector,PdsNIVector *X)
+/** \fn int pds_nvector_connect_input_with_nivector(PdsNVector *NVector,PdsNIVector *X)
  *  \brief Conecta los elementos del vector X de neuronas de entradas, con las 
  *  entradas X[id] de las neuronas del vector NVector.
+ *
  *  Si existen mas entradas de NVector que elementos de X las entradas quedan
  *  desconectadas cargadas con NULL.
  *  Si existen menos entradas de NVector que elementos de X los elementos quedan
@@ -222,7 +217,7 @@ int pds_nvector_connect_input(PdsNVector *NVector,PdsNVector *NVectorX)
  *  \return TRUE si todo fue bien o FALSE si no(ej: NVector==NULL, X==NULL). 
  *  \ingroup PdsNVectorGroup
  */
-int pds_nvector_connect_input_data(PdsNVector *NVector,PdsNIVector *X)
+int pds_nvector_connect_input_with_nivector(PdsNVector *NVector,PdsNIVector *X)
 {
 	PdsNnNatural i,j;
 
@@ -243,51 +238,47 @@ int pds_nvector_connect_input_data(PdsNVector *NVector,PdsNIVector *X)
 
 /** \fn int pds_nvector_evaluate_theta(PdsNVector *NVector)
  *  \brief Evalua la variable theta de la Neurona Neuron.
- *  \f[ \theta=\sum_{i=0}^{N_{el}-1}{W[i]X[i]} - U \f].
- *  \param[in,out] NVector La neurona a evaluar.
+ *  \f[ \theta_j=\sum_{k=0}^{N_{d}-1}{W_{kj}X_k} - U_j \f]
+ *  \param[in,out] NVector El vector de neuronas a evaluar.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
  *  \ingroup PdsNVectorGroup
  */
 int pds_nvector_evaluate_theta(PdsNVector *NVector)
 {
-	PdsNnReal theta;
-	PdsNnNatural i,j;
+	PdsNnNatural j;
+    int dat;
 
 	if(NVector==NULL)		return FALSE;
 
 	for(j=0;j<NVector->Nel;j++)
 	{
-		theta=-NVector->V[j]->U;
-		for(i=0;i<NVector->V[j]->Nel;i++)	
-		{
-			if(NVector->V[j]->X[i]!=NULL)
-			theta=theta+(*(NVector->V[j]->X[i]))*NVector->V[j]->W[i];
-		}
-		NVector->V[j]->Theta=theta;
+        if((NVector->V[j])==NULL)  return FALSE;
+        dat=pds_neuron_evaluate_theta(NVector->V[j]);
+        if(dat==FALSE)  return FALSE;
 	}
 	return TRUE;
 }
 
 
-/** \fn int pds_nvector_evaluate_f(PdsNVector *NVector)
+/** \fn int pds_nvector_evaluate_func(PdsNVector *NVector)
  *  \brief Evalua la funcion de activación de las Neuronas de NVector.
- *  \f[ f(\theta)=\frac{2}{1+e^{-\frac{\theta}{\sigma}}} -1 \f].
+ *  \f[ func\left(\frac{\theta_j}{\sigma_j}\right) \f]
  *  \param[in,out] NVector El vector de neuronas a evaluar.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
  *  \ingroup PdsNVectorGroup
  */
-int pds_nvector_evaluate_f(PdsNVector *NVector)
+int pds_nvector_evaluate_func(PdsNVector *NVector)
 {
-	PdsNnReal x;
+	int dat;
 	PdsNnNatural i;
 
 	if(NVector==NULL)		return FALSE;
 
 	for(i=0;i<NVector->Nel;i++)
 	{
-		x=NVector->V[i]->Theta/NVector->V[i]->Sigma;
-
-		NVector->V[i]->F=(2.0/(1.0+exp(-x)))-1.0;
+        if((NVector->V[i])==NULL)  return FALSE;
+        dat=pds_neuron_evaluate_func(NVector->V[i]);
+        if(dat==FALSE)  return FALSE;
 	}
 	return TRUE;
 }
@@ -295,8 +286,8 @@ int pds_nvector_evaluate_f(PdsNVector *NVector)
 
 /** \fn int pds_nvector_evaluate(PdsNVector *NVector)
  *  \brief Evalua las neuronas del vector NVector.
- *  \f[ \theta=\sum_{i=0}^{N_{el}-1}{W[i]X[i]} - U \f].
- *  \f[ f(\theta)=\frac{2}{1+e^{-\frac{\theta}{\sigma}}} -1 \f].
+ *  \f[ \theta_j=\sum_{k=0}^{N_{d}-1}{W_{kj}X_k} - U_j \f]
+ *  \f[ func\left(\frac{\theta_j}{\sigma_j}\right) \f]
  *  \param[in,out] NVector El vector de neuronas a evaluar.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
  *  \ingroup PdsNVectorGroup
@@ -308,7 +299,7 @@ int pds_nvector_evaluate(PdsNVector *NVector)
 
 	m=pds_nvector_evaluate_theta(NVector);
 	if(m==FALSE)	return FALSE;
-	m=pds_nvector_evaluate_f(NVector);
+	m=pds_nvector_evaluate_func(NVector);
 	if(m==FALSE)	return FALSE;
 
 	return TRUE;
@@ -317,7 +308,7 @@ int pds_nvector_evaluate(PdsNVector *NVector)
 
 /** \fn int pds_nvector_update(PdsNVector *NVector)
  *  \brief Actualiza el valor a la salida de las neuronas NVector
- *  \f[ Y=f(\theta) \f].
+ *  \f[ y_j \leftarrow func\left(\frac{\theta_j}{\sigma_j}\right) \f]
  *  \param[in,out] NVector El vector de neuronas a trabajar.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
  *  \ingroup PdsNVectorGroup
@@ -325,13 +316,16 @@ int pds_nvector_evaluate(PdsNVector *NVector)
 int pds_nvector_update(PdsNVector *NVector)
 {
 	PdsNnNatural i;
+    int dat;
 
 	if(NVector==NULL)		return FALSE;
 
 	for(i=0;i<NVector->Nel;i++)
 	{
-		*(NVector->V[i]->Y)=NVector->V[i]->F;
-		NVector->V[i]->Y[1]=0.0;
+        if((NVector->V[i])==NULL)  return FALSE;
+
+        dat=pds_neuron_update(NVector->V[i]);
+        if(dat==FALSE)  return FALSE;
 	}
 
 	return TRUE;
@@ -340,9 +334,8 @@ int pds_nvector_update(PdsNVector *NVector)
 
 /** \fn int pds_nvector_iterate(PdsNVector *NVector)
  *  \brief Itera las neuronas del vector NVector.
- *  \f[ \theta=\sum_{i=0}^{N_{el}-1}{W[i]X[i]} - U \f].
- *  \f[ f(\theta)=\frac{2}{1+e^{-\frac{\theta}{\sigma}}} -1 \f].
- *  \f[ Y=f(\theta) \f].
+ *  \f[ \theta_j=\sum_{k=0}^{N_{d}-1}{W_{kj}X_k} - U_j \f]
+ *  \f[ y_j \leftarrow func\left(\frac{\theta_j}{\sigma_j}\right) \f]
  *  \param[in,out] NVector El vector de neuronas a iterar.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
  *  \ingroup PdsNVectorGroup
@@ -356,41 +349,41 @@ int pds_nvector_iterate(PdsNVector *NVector)
 
 	m=pds_nvector_evaluate_theta(NVector);
 	if(m==FALSE)	return FALSE;
-	m=pds_nvector_evaluate_f(NVector);
+	m=pds_nvector_evaluate_func(NVector);
 	if(m==FALSE)	return FALSE;
 
-	for(i=0;i<NVector->Nel;i++)
-	{
-		*(NVector->V[i]->Y)=NVector->V[i]->F;
-		NVector->V[i]->Y[1]=0.0;
-	}
+    m=pds_nvector_update(NVector);
+	if(m==FALSE)	return FALSE;
 
 	return TRUE;
 }
 
 
-/** \fn int pds_nvector_evaluate_e(PdsNVector *NVector,const PdsVector *Y)
- *  \brief Compara la salida de las neuronas del vector NVector con el vector Y
- *  el resultado es cargado en la salida Y[1] de cada neurona del vector NVector:
- *  NVector->V[i]->Y[1].
+/** \fn int pds_nvector_evaluate_error(PdsNVector *NVector,const PdsVector * R)
+ *  \brief Compara la salida de las neuronas del vector NVector con el vector de 
+ *  referencia R, el resultado es cargado en la salida Y[1] de cada neurona del 
+ *  vector NVector en  NVector->V[i]->Y[1].
+ *
  *  Los tamaños de los vectores deben ser iguales.
  *  \param[in,out] NVector El vector de neuronas a comparar.
- *  \param[in] Y El vector a comparar.
+ *  \param[in]  R El vector a comparar.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
  *  \ingroup PdsNVectorGroup
  */
-int pds_nvector_evaluate_e(PdsNVector *NVector,const PdsVector *Y)
+int pds_nvector_evaluate_error(PdsNVector *NVector,const PdsVector * R)
 {
 	PdsNnNatural i;
 	int m;
 
 	if(NVector==NULL)		return FALSE;
-	if(NVector->Nel!=Y->Nel)	return FALSE;
+	if(NVector->Nel!= R->Nel)	return FALSE;
 
 	for(i=0;i<NVector->Nel;i++)
 	{
-		NVector->V[i]->Y[1]=Y->V[i]-NVector->V[i]->Y[0];
-		//pds_neuron_evaluate_e(NVector->V[i],Y->V[i]);
+        if((NVector->V[i])==NULL)  return FALSE;
+
+		NVector->V[i]->Y[1]=R->V[i]-NVector->V[i]->Y[0];
+		//pds_neuron_evaluate_error(NVector->V[i],R->V[i]);
 	}
 
 	return TRUE;
@@ -415,6 +408,8 @@ int pds_nvector_get_rms_error(const PdsNVector *NVector,PdsNnReal *RmsError)
 
 	for(i=0;i<NVector->Nel;i++)
 	{
+        if((NVector->V[i])==NULL)  return FALSE;
+
 		(*RmsError)=(*RmsError)+NVector->V[i]->Y[1]*NVector->V[i]->Y[1];
 	}
 	(*RmsError)=sqrt((*RmsError)/NVector->Nel);
@@ -425,7 +420,9 @@ int pds_nvector_get_rms_error(const PdsNVector *NVector,PdsNnReal *RmsError)
 
 /** \fn int pds_nvector_get_hard_vote(const PdsNVector *NVector,PdsNnReal *Vote)
  *  \brief Evalúa una votación de todos los valores de salida Y[0] de las
- *  neuronas, se considera como un voto positivo "+1" cualquier valor mayor o 
+ *  neuronas.
+ *
+ *  Se considera como un voto positivo "+1" cualquier valor mayor o 
  *  igual a "0". Se considera como un voto negativo "-1" cualquier valor menor 
  *  a "0". Luego se realiza la suma con signo de las votaciones.
  *  \param[in,out] NVector El vector de neuronas a trabajar.
@@ -443,6 +440,8 @@ int pds_nvector_get_hard_vote(const PdsNVector *NVector,PdsNnReal *Vote)
 
 	for(i=0;i<NVector->Nel;i++)
 	{
+        if((NVector->V[i])==NULL)  return FALSE;
+
 		if(NVector->V[i]->Y[0]>=0)	(*Vote)=(*Vote)+1.0;
 		else				(*Vote)=(*Vote)-1.0;
 	}
@@ -469,6 +468,8 @@ int pds_nvector_get_soft_vote(const PdsNVector *NVector,PdsNnReal *Vote)
 
 	for(i=0;i<NVector->Nel;i++)
 	{
+        if((NVector->V[i])==NULL)  return FALSE;
+
 		(*Vote)=(*Vote)+NVector->V[i]->Y[0];
 	}
 
@@ -479,7 +480,11 @@ int pds_nvector_get_soft_vote(const PdsNVector *NVector,PdsNnReal *Vote)
  *  \brief Retro propaga el error de las neuronas del vector NVector
  *  el resultado es cargado en la salida Y[1] de cada neurona del vector NVector
  *  conectada a las entradas.
- *  \param[in,out] NVector El vector de neuronas retropropagar el error.
+ *  \f[ e_k \leftarrow e_k + \frac{func'\left(\frac{\theta_j}{\sigma_j}\right)}{\sigma_j} W_{kj} e_j \f]
+ *
+ *  \image html backpropagation.png "Retropropagación del error en las neuronas." 
+ *  \image html nvector_error_prop.png "Retropropagación del error en las neuronas." 
+ *  \param[in,out] NVector El vector de neuronas a retropropagar el error.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
  *  \ingroup PdsNVectorGroup
  */
@@ -492,6 +497,8 @@ int pds_nvector_backpropagate_error(PdsNVector *NVector)
 
 	for(i=0;i<NVector->Nel;i++)
 	{
+        if((NVector->V[i])==NULL)  return FALSE;
+
 		m=pds_neuron_backpropagate_error(NVector->V[i]);	
 		if(m==FALSE)	return FALSE;
 	}
@@ -501,10 +508,10 @@ int pds_nvector_backpropagate_error(PdsNVector *NVector)
 
 
 /** \fn int pds_nvector_update_weight(PdsNVector *NVector, PdsNnReal Alpha)
- *  \brief Actualiza los pesos W[i] de las neuronas.
- *  \f[ \triangle W[i]= \alpha e f'(\theta) X[i] \f].
- *  "e" es el error de la salida da neurona Neuron :Neuron->Y[1].
- *  "f" es la función de activación da neurona Neuron.
+ *  \brief Actualiza los pesos W[k]j de las neuronas.
+ *  \f[ \triangle W_{kj}= \alpha e_j \frac{func'\left(\frac{\theta_j}{\sigma_j}\right)}{\sigma_j} X_k \f]
+ *  "ej" es el error de la salida de la j-essima neurona.
+ *  "func" es la función de activación da neurona.
  *  \param[in,out] NVector El vector de neuronas a actualizar los pesos.
  *  \param[in] Alpha Factor de aprendizaje de los pesos.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
@@ -527,39 +534,12 @@ int pds_nvector_update_weight(PdsNVector *NVector, PdsNnReal Alpha)
 }
 
 
-/** \fn int pds_nvector_update_weight_norm(PdsNVector *NVector, PdsNnReal Alpha,PdsSnReal XtX)
- *  \brief Actualiza los pesos W[i] de las neuronas.
- *  \f[ \triangle W[i]= \alpha e f'(\theta) \frac{X[i]}{X^TX} \f].
- *  "e" es el error de la salida da neurona Neuron :Neuron->Y[1].
- *  "f" es la función de activación da neurona Neuron.
- *  \param[in,out] NVector El vector de neuronas a actualizar los pesos.
- *  \param[in] Alpha Factor de aprendizaje de los pesos.
- *  \param[in] XtX Suma cuadrática de los valores de entrada X[i].
- *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
- *  \ingroup PdsNVectorGroup
- */
-int pds_nvector_update_weight_norm(PdsNVector *NVector, PdsNnReal Alpha,PdsSnReal XtX)
-{
-	PdsNnNatural i;
-	int m;
-
-	if(NVector==NULL)		return FALSE;
-
-	for(i=0;i<NVector->Nel;i++)
-	{
-		m=pds_neuron_update_weight_norm(NVector->V[i],Alpha,XtX);	
-		if(m==FALSE)	return FALSE;
-	}
-
-	return TRUE;
-}
-
 
 /** \fn int pds_nvector_update_weight_normalized(PdsNVector *NVector, PdsNnReal Alpha)
- *  \brief Actualiza los pesos W[i] de las neuronas.
- *  \f[ \triangle W[i]= \alpha e f'(\theta) \frac{X[i]}{X^TX} \f].
- *  "e" es el error de la salida da neurona Neuron :Neuron->Y[1].
- *  "f" es la función de activación da neurona Neuron.
+ *  \brief Actualiza los pesos W[k]j de las neuronas.
+ *  \f[ \triangle W_{kj}= \alpha e_j \frac{func'\left(\frac{\theta_j}{\sigma_j}\right)}{\sigma_j} \frac{X_k}{X^TX} \f]
+ *  "ej" es el error de la salida de la j-essima neurona.
+ *  "func" es la función de activación da neurona.
  *  \param[in,out] NVector El vector de neuronas a actualizar los pesos.
  *  \param[in] Alpha Factor de aprendizaje de los pesos.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL). 
@@ -583,7 +563,7 @@ int pds_nvector_update_weight_normalized(PdsNVector *NVector, PdsNnReal Alpha)
 
 
 /** \fn int pds_nvector_fprintf(const PdsNVector *NVector, FILE *fd)
- *  \brief Guarda en un archivo de texto los pesos W[i] y el valor de U.
+ *  \brief Guarda en un archivo de texto los pesos \f$W_{kj}\f$ y los valores \f$\{U_j,\sigma_j\}\f$.
  *  Ocupando una linea cada uno, y separando los elementos por un TAB.
  *  \param[in] NVector El vector de neuronas a leer.
  *  \param[in,out] fd Manejador del fichero a escribir.
@@ -609,7 +589,7 @@ int pds_nvector_fprintf(const PdsNVector *NVector, FILE *fd)
 
 
 /** \fn int pds_nvector_fscanf(PdsNVector *NVector, FILE *fd)
- *  \brief Lee de un archivo de texto los pesos W[i] y el valor de U.
+ *  \brief Lee de un archivo de texto los pesos \f$W_{kj}\f$ y los valores \f$\{U_j,\sigma_j\}\f$.
  *  Ocupando una linea cada uno, y separando los elementos por un TAB.
  *  \param[out] NVector El vector a escribir.
  *  \param[in,out] fd Manejador del fichero a leer.
@@ -636,7 +616,7 @@ int pds_nvector_fscanf(PdsNVector *NVector, FILE *fd)
 
 
 /** \fn int pds_nvector_fwrite(const PdsNVector *NVector, FILE *fd)
- *  \brief Guarda en un archivo de texto binario los pesos W[i] y el valor de U.
+ *  \brief Guarda en un archivo de texto binario los pesos \f$W_{kj}\f$ y los valores \f$\{U_j,\sigma_j\}\f$.
  *  \param[in] NVector El vector de neuronas a leer.
  *  \param[in,out] fd Manejador del fichero binario a escribir.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL o fd==NULL). 
@@ -661,7 +641,7 @@ int pds_nvector_fwrite(const PdsNVector *NVector, FILE *fd)
 
 
 /** \fn int pds_nvector_fread(PdsNVector *NVector, FILE *fd)
- *  \brief Lee de un archivo de texto binario los pesos W[i] y el valor de U.
+ *  \brief Lee de un archivo de texto binario los pesos \f$W_{kj}\f$ y los valores \f$\{U_j,\sigma_j\}\f$.
  *  \param[out] NVector El vector a escribir.
  *  \param[in,out] fd Manejador del fichero binario a leer.
  *  \return TRUE si todo fue bien o FALSE si no (ej: NVector==NULL o fd==NULL). 
