@@ -20,27 +20,16 @@
  * 
  */
 
-/** \file pdsnn.h
- * \brief Archivo de definición de cabeceras.
- *
- *  Puedes habilitar todos los módulos de la biblioteca  
- *  usando este archivo, haciendo:
-   @verbatim
-	#include <pds/pdsnn.h>
-   @endverbatim
- * O puedes habilitarlas una por una usando lo siguiente:
-   @verbatim
-	#include <pds/pdsnivector.h>
-	#include <pds/pdsnvector.h>
-	#include <pds/pdsneuronml.h>
-   @endverbatim
- * 
- */
-
 
 #ifndef __PDSNN_H__
 #define __PDSNN_H__
 
+#define PDS_DEFAULT_MAX_RMS_ERROR 0.70711
+#define PDS_DEFAULT_ALPHA 0.5
+#define PDS_DEFAULT_MAX_ITER 0
+
+#include <pds/pdsnnglobal.h>
+
 #include <pds/pdsnivector.h>
 #include <pds/pdsnvector.h>
 #include <pds/pdsneuronml.h>
